.. _ismags:

****************
ISMAGS Algorithm
****************

.. automodule:: networkx.algorithms.isomorphism.ismags

ISMAGS object
-------------
.. currentmodule:: networkx.algorithms.isomorphism

.. autosummary::
    :toctree: generated/

     ISMAGS
     ISMAGS.analyze_symmetry
     ISMAGS.is_isomorphic
     ISMAGS.subgraph_is_isomorphic
     ISMAGS.isomorphisms_iter
     ISMAGS.subgraph_isomorphisms_iter
     ISMAGS.largest_common_subgraph

